import {useNavigate, useParams, useSearchParams} from "react-router-dom"
import TrainsTable from "./TrainsTable"
import TripsFilter from "./TripsFilter"
import {useState} from "react"
import {Box, Button, FormLabel} from "@mui/material"
import {DateTimePicker} from "@mui/x-date-pickers"
import dayjs from "dayjs"
import {useQuery, useQueryClient} from "@tanstack/react-query"
import AutocompleteStation from "./AutocompleteStation"

function DateTimeSelector({datetime, setDatetime}) {
  const navigate = useNavigate()

  function onStationSelected(event, station) {
    if (station !== null)
      navigate(`/station/sncf/${station.id}/`)
  }

  return <>
    <Box component="form" display="flex" alignItems="center" sx={{'& .MuiTextField-root': { m: 1, width: '25ch' },}}>
        <FormLabel>
          Changer la gare recherchée :
        </FormLabel>
        <AutocompleteStation onChange={onStationSelected} />
        <FormLabel>
          Modifier la date et l'heure de recherche :
        </FormLabel>
        <DateTimePicker name="date" label="Date" onChange={setDatetime} value={datetime} />
        <Button type="submit">Rechercher</Button>
    </Box>
  </>
}

function Station() {
  // eslint-disable-next-line no-unused-vars
  let {theme, stationId} = useParams()
  // eslint-disable-next-line no-unused-vars
  let [searchParams, setSearchParams] = useSearchParams()
  const [datetime, setDatetime] = useState(dayjs())

  useQueryClient()
  const stationQuery = useQuery({
    queryKey: ['station', stationId],
    queryFn: () => fetch(`${process.env.REACT_APP_MOTIS_SERVER}/api/v1/stoptimes?stopId=${stationId}&n=1`)
      .then(response => response.json()),
    enabled: !!stationId,
  })
  const station = stationQuery.data?.stopTimes[0].place ?? {name: "Chargement…"}

  if (searchParams.get("time") === undefined) {
    setInterval(() => {
      setDatetime(dayjs())
    }, 5000)
  }

  return (
    <div className="Station">
      <header className="App-header">
        <h1>Horaires en gare de {station.name}</h1>
      </header>

      <main>
        <DateTimeSelector datetime={datetime} setDatetime={setDatetime} />
        <TripsFilter />
        <TrainsTable station={station} datetime={datetime} tableType="departures" />
        <TrainsTable station={station} datetime={datetime} tableType="arrivals" />
      </main>
    </div>
  )
}

export default Station;
